# CLICanvas

CLICanvas is a python library that deals with terminal-based user input.
From a TUI framework to custom input functions.

## Features

- Custom input function and modes, including a mirror of readline and getpass
